from setuptools import setup, find_packages

setup(
    name='abdi',
    version='1.0.0',
    author='Shiu Ming Fang',
    author_email='avatar.xu@gmail.com',
    description='Agent BDI framework',
    packages=find_packages(),
)